Learn R Programming

powerindexR (version 1.6)

QMWC: Obtain the quasi-minimal winning coalitions

Description

This function determines the quasi-minimal winning coalitions in a weighted majority game.

Usage

QMWC(quota, weights)

Value

Number of Quasi-Minimal Winning Coalitions

Total amount of Quasi-Minimal Winning Coalitions.

Quasi-Minimal Winning Coalitions

Each row indicates a binary representation of each Quasi-Minimal Winning Coalition.

Arguments

quota

Numerical value that represents the majority in a given voting.

weights

Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.

Author

Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.

Examples

Run this code
weights<-c(137,85,71,32,9,8,5,2,1) 
quota<-176
QMWC(quota,weights)

Run the code above in your browser using DataLab