Learn R Programming

powerindexR (version 1.6)

pi.colomermartinez: Power based on the Colomer-Martinez index.

Description

This function determines the distribution of the power based on the Colomer-Martinez index.

Usage

pi.colomermartinez(quota, weights, minimal = FALSE)

Value

Colomer-Martinez

The Colomer-Martinez index.

Number of Minimal Winning Coalitions

Total amount of Minimal Winning Coalitions.

Minimal Winning Coalitions

Each row indicates a binary representation of each Minimal Winning Coalition.

Arguments

quota

Numerical value that represents the majority in a given voting.

weights

Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.

minimal

Logical option to obtain the Minimal Winning Coalitions.

Author

Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.

References

Colomer, J. M., & Martinez, F. (1995). The paradox of coalition trading. Journal of Theoretical Politics, 7(1), 41-63.

Examples

Run this code
weights<-c(137,85,71,32,9,8,5,2,1) 
quota<-176
pi.colomermartinez(176,weights,minimal=TRUE)

Run the code above in your browser using DataLab