Learn R Programming

powerindexR (version 1.6)

pi.johnston: Power based on the Johnston index.

Description

This function determines the distribution of the power based on the Johnston index.

Usage

pi.johnston(quota, weights, quasiminimal = FALSE)

Value

Johnston

The Jonhston index.

Number of Quasi-Minimal Winning Coalitions

Total amount of Quasi-Minimal Winning Coalitions.

Quasi-Minimal Winning Coalitions

Each row indicates a binary representation of each Quasi-Minimal Winning Coalition.

Arguments

quota

Numerical value that represents the majority in a given voting.

weights

Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.

quasiminimal

Logical option to obtain the Quasi-Minimal Winning Coalitions.

Author

Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.

References

Johnston, R. J. (1978). On the measurement of power: Some reactions to Laver. Environment and Planning A, 10(8), 907-914.

Examples

Run this code
weights<-c(137,85,71,32,9,8,5,2,1) 
quota<-176
pi.johnston(176,weights,quasiminimal=TRUE)

Run the code above in your browser using DataLab