Learn R Programming

powerindexR (version 1.6)

pi.johnstoncolomermartinez: Power based on the Jonhston-Colomer-Martinez index.

Description

This function determines the distribution of the power based on the Jonhston-Colomer-Martinez index.

Usage

pi.johnstoncolomermartinez(quota, weights)

Value

Jonhston-Colomer-Martinez

The Jonhston-Colomer-Martinez index.

Arguments

quota

Numerical value that represents the majority in a given voting.

weights

Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.

Author

Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.

References

Colomer, J. M., & Martinez, F. (1995). The paradox of coalition trading. Journal of Theoretical Politics, 7(1), 41-63.

Johnston, R. J. (1978). On the measurement of power: Some reactions to Laver. Environment and Planning A, 10(8), 907-914.

Examples

Run this code
weights<-c(137,85,71,32,9,8,5,2,1) 
quota<-176
pi.johnstoncolomermartinez(176,weights)

Run the code above in your browser using DataLab