powered by
This function determines the distribution of the power based on the Colomer-Martinez index.
pi.colomermartinez(quota, weights, minimal = FALSE)
The Colomer-Martinez index.
Total amount of Minimal Winning Coalitions.
Each row indicates a binary representation of each Minimal Winning Coalition.
Numerical value that represents the majority in a given voting.
Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.
Logical option to obtain the Minimal Winning Coalitions.
Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.
Colomer, J. M., & Martinez, F. (1995). The paradox of coalition trading. Journal of Theoretical Politics, 7(1), 41-63.
weights<-c(137,85,71,32,9,8,5,2,1) quota<-176 pi.colomermartinez(176,weights,minimal=TRUE)
Run the code above in your browser using DataLab