powered by
This function determines the distribution of the power based on the Johnston index.
pi.johnston(quota, weights, quasiminimal = FALSE)
The Jonhston index.
Total amount of Quasi-Minimal Winning Coalitions.
Each row indicates a binary representation of each Quasi-Minimal Winning Coalition.
Numerical value that represents the majority in a given voting.
Numerical vector of dimension \(n\) that indicates the weights of \(n\) agents in a given voting.
Logical option to obtain the Quasi-Minimal Winning Coalitions.
Livino M. Armijos-Toro, Jose M. Alonso-Meijide, Manuel A. Mosquera, Alejandro Saavedra-Nieves.
Johnston, R. J. (1978). On the measurement of power: Some reactions to Laver. Environment and Planning A, 10(8), 907-914.
weights<-c(137,85,71,32,9,8,5,2,1) quota<-176 pi.johnston(176,weights,quasiminimal=TRUE)
Run the code above in your browser using DataLab